#[shared]Expand description
Marks a file or inline mod as shared-stage code for transpilation.
Shared modules may be required by any other stage.
#[shared]Marks a file or inline mod as shared-stage code for transpilation.
Shared modules may be required by any other stage.